=== modified file 'charmworld/jobs/ingest.py'
--- charmworld/jobs/ingest.py	2013-07-31 14:41:29 +0000
+++ charmworld/jobs/ingest.py	2013-08-01 15:12:08 +0000
@@ -674,6 +674,10 @@
     charm['downloads_in_past_30_days'] = count
     count = store.get_download_counts(charm)
     charm['downloads'] = count[0][0] if count else 0
+    count = store.count_downloads_in_days(charm, 7, date.today())
+    charm['downloads_in_past_7_days'] = count
+    count = store.count_downloads_in_days(charm, 182, date.today())
+    charm['downloads_in_past_half_year'] = count
 
 
 def update_date_created(charm, log):

=== modified file 'charmworld/jobs/tests/test_cstat.py'
--- charmworld/jobs/tests/test_cstat.py	2013-07-04 18:48:48 +0000
+++ charmworld/jobs/tests/test_cstat.py	2013-08-01 15:12:08 +0000
@@ -1,11 +1,15 @@
 # Copyright 2012, 2013 Canonical Ltd.  This software is licensed under the
 # GNU Affero General Public License version 3 (see the file LICENSE).
 
+from datetime import datetime
 import logging
 
 from pyelasticsearch import ElasticSearch
 from requests import Response
-
+from urlparse import (
+    parse_qsl,
+    urlparse,
+)
 from charmworld.charmstore import CharmStore
 from charmworld.jobs.cstat import update_counts
 from charmworld.models import CharmSource
@@ -32,9 +36,26 @@
             @staticmethod
             def send(request):
                 response = Response()
-                if ('start' in request.url):
-                    response._content = ('[["2010-12-24", 4],'
-                                         ' ["2010-12-25", 1]]')
+                params = dict(parse_qsl(urlparse(request.url).query))
+                if ('start' in params):
+                    start = datetime.strptime(params['start'], '%Y-%m-%d')
+                    end = datetime.strptime(params['end'], '%Y-%m-%d')
+                    days = (end - start).days
+                    if days == 7:
+                        response._content = ('[["2010-12-24", 4],'
+                                             ' ["2010-12-25", 1]]')
+                    elif days == 30:
+                        response._content = ('[["2010-12-24", 10],'
+                                             ' ["2010-12-24", 4],'
+                                             ' ["2010-12-25", 1]]')
+                    elif days == 182:
+                        response._content = ('[["2010-12-23", 10],'
+                                             ' ["2010-12-24", 4],'
+                                             ' ["2010-12-25", 1]]')
+                        response._content = ('[["2010-12-22", 100],'
+                                             ' ["2010-12-23", 10],'
+                                             ' ["2010-12-24", 4],'
+                                             ' ["2010-12-25", 1]]')
                 else:
                     response._content = '[[25]]'
                 return response
@@ -42,10 +63,14 @@
         store.session = FakeSession
         update_counts(CharmSource(self.db, index_client), store, log)
         db_charm = self.db.charms.find_one({'_id': charm_id})
-        self.assertEqual(5, db_charm['downloads_in_past_30_days'])
+        self.assertEqual(5, db_charm['downloads_in_past_7_days'])
+        self.assertEqual(15, db_charm['downloads_in_past_30_days'])
+        self.assertEqual(115, db_charm['downloads_in_past_half_year'])
         self.assertEqual(25, db_charm['downloads'])
         index_charm = index_client.get(charm_id)
-        self.assertEqual(5, index_charm['downloads_in_past_30_days'])
+        self.assertEqual(5, index_charm['downloads_in_past_7_days'])
+        self.assertEqual(15, index_charm['downloads_in_past_30_days'])
+        self.assertEqual(115, index_charm['downloads_in_past_half_year'])
         self.assertEqual(25, index_charm['downloads'])
 
     def test_update_no_index(self):

=== modified file 'charmworld/models.py'
--- charmworld/models.py	2013-07-31 17:02:52 +0000
+++ charmworld/models.py	2013-08-02 10:27:28 +0000
@@ -226,7 +226,9 @@
 
         # Provided by the charm store job.
         'downloads': 0,
+        'downloads_in_past_7_days': 0,
         'downloads_in_past_30_days': 0,
+        'downloads_in_past_half_year': 0,
         'store_data': {},
         'store_url': '',
 
@@ -444,6 +446,13 @@
         return self._representation['downloads']
 
     @property
+    def downloads_in_past_7_days(self):
+        """The number of times the charm was downloaded in the past 7 days.
+
+        The number comes from the store. It does not equate to deploys."""
+        return self._representation['downloads_in_past_7_days']
+
+    @property
     def downloads_in_past_30_days(self):
         """The number of times the charm was downloaded in the past 30 days.
 
@@ -451,6 +460,13 @@
         return self._representation['downloads_in_past_30_days']
 
     @property
+    def downloads_in_past_half_year(self):
+        """The number of times the charm was downloaded in the past half year.
+
+        The number comes from the store. It does not equate to deploys."""
+        return self._representation['downloads_in_past_half_year']
+
+    @property
     def proof(self):
         """The dict charm's proof warnings and errors."""
         return self._representation['proof']

=== modified file 'charmworld/templates/charm.pt'
--- charmworld/templates/charm.pt	2013-07-08 18:49:08 +0000
+++ charmworld/templates/charm.pt	2013-08-02 11:07:30 +0000
@@ -92,7 +92,17 @@
             <br />
             lp:${charm.branch_spec}
           </div>
-
+          <div class="field">
+            <b>Downloads</b><br/>
+            in past 7 days:
+            <span tal:replace="charm.downloads_in_past_7_days"/><br/>
+            in past 30 days:
+            <span tal:replace="charm.downloads_in_past_30_days"/><br/>
+            in past half year:
+            <span tal:replace="charm.downloads_in_past_half_year"/><br/>
+            all:
+            <span tal:replace="charm.downloads"/>
+          </div>
         </div>
 
         <div class="span3">

=== modified file 'charmworld/tests/test_models.py'
--- charmworld/tests/test_models.py	2013-07-31 17:02:52 +0000
+++ charmworld/tests/test_models.py	2013-08-02 10:27:28 +0000
@@ -252,6 +252,24 @@
         charm = Charm({})
         self.assertEquals(0, charm.downloads_in_past_30_days)
 
+    def test_downloads_in_past_7_days(self):
+        # The downloads_in_past_7_days property is an int.
+        charm_data = {'downloads_in_past_7_days': 7}
+        charm = Charm(charm_data)
+        self.assertEqual(7, charm.downloads_in_past_7_days)
+        # The default is zero.
+        charm = Charm({})
+        self.assertEquals(0, charm.downloads_in_past_7_days)
+
+    def test_downloads_in_past_half_year(self):
+        # The downloads_in_past_half_year property is an int.
+        charm_data = {'downloads_in_past_half_year': 180}
+        charm = Charm(charm_data)
+        self.assertEqual(180, charm.downloads_in_past_half_year)
+        # The default is zero.
+        charm = Charm({})
+        self.assertEquals(0, charm.downloads_in_past_half_year)
+
     def test_store_url(self):
         # The store_url property is a string.
         charm_data = {'store_url': 'cs:~owner/series/name-1'}

=== modified file 'charmworld/views/tests/test_charms.py'
--- charmworld/views/tests/test_charms.py	2013-07-19 12:51:01 +0000
+++ charmworld/views/tests/test_charms.py	2013-08-02 10:27:28 +0000
@@ -64,7 +64,9 @@
     },
     'doctype': 'charm',
     'downloads': 0,
+    'downloads_in_past_7_days': 0,
     'downloads_in_past_30_days': 0,
+    'downloads_in_past_half_year': 0,
     'files': {
         'readme': {
             'subdir': '',

